# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/pqc/coin/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Pqc\\Coin\\": "packages/pqc/coin/src",
            "Pqc\\Coin\\Seeders\\": "packages/pqc/coin/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Pqc\Coin\Providers\CoinServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Coin'  => Pqc\Coin\Facades\Coin::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Pqc\\Coin\\Seeders\\CoinTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Pqc\Coin\Providers\CoinServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Pqc\Coin\Providers\CoinServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Pqc\Coin\Providers\CoinServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/coin/{modulename}

**User**

    http://path-to-route-folder/user/coin/{modulename}

**Public**

    http://path-to-route-folder/coins


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/coin/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/coin/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/coin/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/coin/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/coin/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/coin/{modulename}/{slug}
    METHOD: GET